@@ -424,7 +424,7 @@ class MQCon:
                 self.declare_queue(self.queue_name, '', self.arguments)
             else:
                 self.declare_queue(self.queue_name, self.router, self.arguments)
-                
+
     def declare_exchange(self, exchange: str, publish_type: str):
         assert exchange or self.exchange, 'Exchange must be declared during initialization or here!'
         assert publish_type or self.publish_type, 'Publish type must be declared during initialization or here!'
@@ -437,7 +437,7 @@ class MQCon:
         publish_type = self.publish_type
         self.channel.exchange_declare(exchange=exchange, exchange_type=publish_type)
 
-    def declare_queue(self, queue_name: str = '', router: str= None, arguments: dict = {}):
+    def declare_queue(self, queue_name: str = '', router: str = None, arguments: dict = {}):
         # x-max-priority x-expires x-message-ttl
         self.queue_name = queue_name
         if self.publish_type == 'normal':
@@ -456,7 +456,8 @@ class MQCon:
             self.channel.basic_publish(exchange='', routing_key=self.queue_name, body=new_data,
                                        properties=pika.BasicProperties(
                                            **dict(
-                                               {'delivery_mode': delivery_mode, 'expiration': expiration, 'priority': priority},
+                                               {'delivery_mode': delivery_mode, 'expiration': expiration,
+                                                'priority': priority},
                                                **kwargs)))
         elif self.publish_type in {'fanout', 'direct'}:
             # assert exchange and not router, 'Exchange must be declared and router must be empty!'
@@ -471,10 +472,9 @@ class MQCon:
                                                 'priority': priority},
                                                **kwargs)))
 
-    def bind_exchange(self, exchange: str='', router: str=None, queue_name: str=''):
+    def bind_exchange(self, exchange: str = '', router: str = None, queue_name: str = ''):
         self.channel.queue_bind(exchange=exchange, queue=queue_name, routing_key=router)
 
-
     def delete_queue(self, queue_name: str):
         self.channel.queue_delete(queue_name)
 
@@ -502,7 +502,7 @@ class ClickhouseCon:
         elif isinstance(char, list):
             return char
 
-    def insert(self, columns: list, values: list, dbname: str='default', tbname: str=None):
+    def insert(self, columns: list, values: list, dbname: str = 'default', tbname: str = None):
         """
         example:
         1. create table test
@@ -582,7 +582,7 @@ class ClickhouseCon:
 
 class KafkaCon:
 
-    def __init__(self, host: str, port: int, username: str, password: str, hosts=None, group_id: str=None):
+    def __init__(self, host: str, port: int, username: str, password: str, hosts=None, group_id: str = None):
         self.host = host
         self.port = port
         self.username = username
@@ -603,7 +603,7 @@ class KafkaCon:
     def producer(self):
         return kafka.KafkaProducer(**self.conf)
 
-    def consumer(self, group_id: str=None):
+    def get_consumer(self, group_id: str = None):
         return kafka.KafkaConsumer(**dict(self.conf, **{'group_id': group_id}))
 
     def partition(self, mapping: dict or list):
@@ -621,12 +621,15 @@ class KafkaCon:
 
     def send(self, topic: str, data: dict, key: str = None, partition: int = None):
         data = bytes(json.dumps(data), encoding='utf8')
-        self.producer.send(topic=topic, value=data, key=key, partition=partition)
+        key = bytes(key, encoding='utf8')
+        result = self.producer.send(topic=topic, value=data, key=key, partition=partition)
+        self.producer.flush()
+        return result
 
     def consume(self, topics: list or str, group_id: str = None):
         if isinstance(topics, str):
             topics = [topics]
-        self.consumer = self.consumer(group_id)
+        self.consumer = self.get_consumer(group_id)
         self.consumer.subscribe(topics)
         for message in self.consumer:
             topic = message.topic
