@@ -20,48 +20,42 @@ class ImageTools:
         return base64.b64decode(img.split('base64,')[-1])
 
     @staticmethod
-    def image_bytes_to_pillow(image_input, input_type='binary'):
-        if input_type == 'base64':
-            bytes_data = base64.decodebytes(image_input)
-        else:
-            bytes_data = image_input
-        buffer = io.BytesIO(bytes_data)
+    def img_array2bytes(img):
+        return cv2.imencode('.png', img)[-1]
+
+    @staticmethod
+    def img_bytes2array(img):
+        img = np.frombuffer(img, np.uint8)
+        img = cv2.imdecode(img, cv2.IMREAD_COLOR)
+        return img
+
+    @staticmethod
+    def img_bytes2pil(img):
+        buffer = io.BytesIO(img)
         image = Image.open(buffer)
         return image
 
     @staticmethod
-    def image_pillow_to_bytes(image_input, output_type='binary'):
+    def img_base642pil(img):
+        bytes_data = base64.decodebytes(image_input)
+        buffer = io.BytesIO(img)
+        image = Image.open(buffer)
+        return image
+
+    @staticmethod
+    def img_pil2bytes(img):
         buffer = io.BytesIO()
-        # image_input = image_input.convert('RGB')
-        image_input.save(buffer, format='JPEG')
+        img.save(buffer, format='PNG')
         image_data = buffer.getvalue()
-        if output_type == 'binary':
-            pass
-        else:
-            image_data = base64.encodebytes(image_data)
         return image_data
 
     @staticmethod
-    def image_binary_to_base64(image_input):
-        if isinstance(image_input, bytes):
-            return base64.encodebytes(image_input)
-        elif repr(image_input)[:4] == '<PIL':
-            buffer = io.BytesIO()
-            image_input.save(buffer, format='JPEG')
-            byte_data = buffer.getvalue()
-            image_data = base64.encodebytes(byte_data)
-            return image_data
-
-    @staticmethod
-    def image_base64_to_binary(image_input):
-        if isinstance(image_input, bytes):
-            return base64.decodebytes(image_input)
-        elif repr(image_input)[:4] == '<PIL':
-            buffer = io.BytesIO()
-            image_input.save(buffer, format='JPEG')
-            byte_data = buffer.getvalue()
-            image_data = base64.encodebytes(byte_data)
-            return image_data
+    def img_pil2base64(img):
+        buffer = io.BytesIO()
+        image_input.save(buffer, format='PNG')
+        image_data = buffer.getvalue()
+        image_data = base64.encodebytes(image_data)
+        return image_data
 
     @staticmethod
     def megera_alpha_img(raw_img, new_img):
@@ -73,7 +67,8 @@ class ImageTools:
         alpha_img2 = new_img[:, :, 3] / 255.0
         alpha = 1 - (1 - alpha_img1) * (1 - alpha_img2)
         for ii in range(3):
-            raw_img[:, :, ii] = (raw_img[:, :, ii] * alpha_img1 * (1 - alpha_img2) + new_img[:, :,ii] * alpha_img2) / alpha
+            raw_img[:, :, ii] = (raw_img[:, :, ii] * alpha_img1 * (1 - alpha_img2) + new_img[:, :,
+                                                                                     ii] * alpha_img2) / alpha
         raw_img[:, :, 3] = alpha * 255
         return
 
